@@ -18,6 +18,10 @@
 # License along with this program; if not, write to the
 # Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 # Boston, MA 02111-1307, USA.
+"""
+Utilities for getting the location of various directories.
+Enables identical use for installed and uninstalled versions.
+"""
 
 import os.path
 import string
@@ -25,13 +29,14 @@ import string
 LIBDIR = '/usr/lib'
 PKGDATADIR = '/usr/share/pitivi'
 PIXMAPDIR = '/usr/share/pixmaps'
-pitivi_version = '0.10.1'
+pitivi_version = '0.10.2'
 APPNAME = 'PiTiVi'
 
 def get_pixmap_dir():
     """ Returns the directory for program-only pixmaps """
     dir = os.path.dirname(os.path.abspath(__file__))
-    if os.path.exists(os.path.join(dir, 'CVS')):
+    if (os.path.exists(os.path.join(dir, 'CVS')) or
+        os.path.exists(os.path.join(dir, '.svn'))):
         root = dir
     else:
         root = PKGDATADIR
@@ -40,7 +45,8 @@ def get_pixmap_dir():
 def get_global_pixmap_dir():
     """ Returns the directory for global pixmaps (ex : application icon) """
     dir = os.path.dirname(os.path.abspath(__file__))
-    if os.path.exists(os.path.join(dir, 'CVS')):
+    if (os.path.exists(os.path.join(dir, 'CVS')) or
+        os.path.exists(os.path.join(dir, '.svn'))):
         root = string.join(dir.split('/')[:-1], '/')
     else:
         root = PIXMAPDIR
