@@ -31,6 +31,9 @@ import gobject
 import gst
 
 import utils
+from settings import ExportSettings
+
+from gettext import gettext as _
 
 class ObjectFactory(gobject.GObject):
     """
@@ -143,15 +146,15 @@ class ObjectFactory(gobject.GObject):
         stl = []
         filename = os.path.basename(unquote(self.name))
         if not self.title:
-            stl.append("<b>%s</b><small>" % gobject.markup_escape_text(filename))
+            stl.append(_("<b>%s</b><small>") % gobject.markup_escape_text(filename))
         else:
             # either 'Title' or 'Title (Artist)'
             if self.artist:
-                stl.append("<b>%s</b> (%s)" % (gobject.markup_escape_text(self.title),
+                stl.append(_("<b>%s</b> (%s)") % (gobject.markup_escape_text(self.title),
                                                gobject.markup_escape_text(self.artist)))
             else:
-                stl.append("<b>%s</b>" % gobject.markup_escape_text(self.title))
-            stl.append("<small><b>File:</b> %s" % filename)
+                stl.append(_("<b>%s</b>") % gobject.markup_escape_text(self.title))
+            stl.append(_("<small><b>File:</b> %s") % filename)
 ##         if self.title:
 ##             stl.append("<b>Title:</b> %s" % self.title)
 ##         if self.artist:
@@ -204,6 +207,10 @@ class FileSourceFactory(ObjectFactory):
 
     def do_set_property(self, property, value):
         if property.name == "length":
+            if self.length and self.length != value:
+                gst.warning("%s : Trying to set a new length (%s) different from previous one (%s)" % (self.name,
+                                                                                                       gst.TIME_ARGS(self.length),
+                                                                                                       gst.TIME_ARGS(value)))
             self.length = value
         elif property.name == "thumbnail":
             if os.path.isfile(value):
@@ -234,13 +241,17 @@ class FileSourceFactory(ObjectFactory):
             if mypad:
                 gst.warning("Removing previous asrc. WHY didn't decodebin remove it??")
                 bin.remove_pad(mypad)
-            bin.add_pad(gst.GhostPad("asrc", pad))
+            asrc = gst.GhostPad("asrc", pad)
+            asrc.set_active(True)
+            bin.add_pad(asrc)
         elif "video" in pad.get_caps().to_string():
             mypad = bin.get_pad("vsrc")
             if mypad:
                 gst.warning("Removing previous vsrc. WHY didn't decodebin remove it??")
                 bin.remove_pad(mypad)
-            bin.add_pad(gst.GhostPad("vsrc", pad))
+            vsrc = gst.GhostPad("vsrc", pad)
+            vsrc.set_active(True)
+            bin.add_pad(vsrc)
         else:
             return
 
@@ -267,6 +278,26 @@ class FileSourceFactory(ObjectFactory):
         """ Sets the thumbnail filename of the element """
         self.set_property("thumbnail", thumbnail)
 
+    def getExportSettings(self):
+        """ Returns the ExportSettings corresponding to this source """
+        settings = ExportSettings()
+        if self.video_info_stream:
+            # Fill video properties
+            vs = self.video_info_stream
+            settings.videowidth = vs.width
+            settings.videoheight = vs.height
+            settings.videorate = vs.framerate
+            settings.videopar = vs.par
+
+        if self.audio_info_stream:
+            # Fill audio properties
+            as = self.audio_info_stream
+            settings.audiochannels = as.channels
+            settings.audiorate = as.rate
+            settings.audiodepth = as.depth
+            
+        return settings
+
 class OperationFactory(ObjectFactory):
     """
     Provides operations useable in a timeline
@@ -359,11 +390,13 @@ class VideoStream(MultimediaStream):
         try:
             self.framerate = struct["framerate"]
         except:
-            self.framerate = None
+            # if no framerate was given, use 1fps
+            self.framerate = gst.Fraction(1,1)
         try:
             self.par = struct["pixel-aspect-ratio"]
         except:
-            self.par = None
+            # use a default setting, None is not valid !
+            self.par = gst.Fraction(1,1)
 
         if self.width and self.height and self.par:
             self.dar = gst.Fraction(self.width * self.par.num, self.height * self.par.denom)
@@ -376,15 +409,15 @@ class VideoStream(MultimediaStream):
     def getMarkup(self):
         if self.raw:
             if self.framerate.num:
-                templ = "<b>Video:</b> %d x %d <i>pixels</i> at %.2f<i>fps</i>"
-                templ = templ % (self.dar.num * self.height / self.dar.denom, self.height, float(self.framerate.num) / float(self.framerate.denom))
+                templ = _("<b>Video:</b> %d x %d <i>pixels</i> at %.2f<i>fps</i>")
+                templ = templ % (self.dar * self.height , self.height, float(self.framerate))
             else:
-                templ = "<b>Image:</b> %d x %d <i>pixels</i>"
-                templ = templ % (self.dar.num * self.height / self.dar.denom, self.height)
+                templ = _("<b>Image:</b> %d x %d <i>pixels</i>")
+                templ = templ % (self.dar * self.height, self.height)
             if self.codec:
-                templ = templ + " <i>(%s)</i>" % self.codec
+                templ = templ + _(" <i>(%s)</i>") % self.codec
             return templ
-        return "<b>Unknown Video format:</b> %s" % self.videotype
+        return _("<b>Unknown Video format:</b> %s") % self.videotype
             
 class AudioStream(MultimediaStream):
 
@@ -419,16 +452,16 @@ class AudioStream(MultimediaStream):
         try:
             self.depth = struct["depth"]
         except:
-            self.depth = None
+            self.depth = self.width
 
     def getMarkup(self):
         if self.raw:
-            templ = "<b>Audio:</b> %d channels at %d <i>Hz</i> (%d <i>bits</i>)"
+            templ = _("<b>Audio:</b> %d channels at %d <i>Hz</i> (%d <i>bits</i>)")
             templ = templ % (self.channels, self.rate, self.width)
             if self.codec:
-                templ = templ + " <i>(%s)</i>" % self.codec
+                templ = templ + _(" <i>(%s)</i>") % self.codec
             return templ
-        return "<b>Unknown Audio format:</b> %s" % self.audiotype
+        return _("<b>Unknown Audio format:</b> %s") % self.audiotype
 
 class TextStream(MultimediaStream):
 
@@ -439,15 +472,16 @@ class TextStream(MultimediaStream):
         self.texttype = self.caps[0].get_name()
 
     def getMarkup(self):
-        return "<b>Text:</b> %s" % self.texttype
+        return _("<b>Text:</b> %s") % self.texttype
 
 def get_stream_for_caps(caps):
     val = caps.to_string()
     if val.startswith("video/"):
         return VideoStream(caps)
-    if val.startswith("audio/"):
+    elif val.startswith("audio/"):
         return AudioStream(caps)
-    if val.startswith("text/"):
+    elif val.startswith("text/"):
         return TextStream(caps)
-    return None
+    else:
+        return None
                      
