@@ -27,16 +27,24 @@ import os
 import gobject
 import gtk
 import gst
+import gconf
 
 import pitivi.instance as instance
 import pitivi.configure as configure
 
+from gettext import gettext as _
+
 from timeline import TimelineWidget
 from sourcefactories import SourceFactoriesWidget
 from viewer import PitiviViewer
 from projectsettings import ProjectSettingsDialog
 from pitivi.configure import pitivi_version, APPNAME
 
+D_G_INTERFACE = "/desktop/gnome/interface"
+
+for gconf_dir in (D_G_INTERFACE,):
+    gconf.client_get_default ().add_dir (gconf_dir, gconf.CLIENT_PRELOAD_NONE)
+
 class PitiviMainWindow(gtk.Window):
     """
     Pitivi's main window
@@ -62,21 +70,23 @@ class PitiviMainWindow(gtk.Window):
     def _setActions(self):
         """ sets up the GtkActions """
         self.actions = [
-            ("NewProject", gtk.STOCK_NEW, None, None, "Create a new project", self._newProjectCb),
-            ("OpenProject", gtk.STOCK_OPEN, None, None, "Opens an existing project", self._openProjectCb),
-            ("SaveProject", gtk.STOCK_SAVE, None, None, "Save the current project", self._saveProjectCb),
-            ("SaveProjectAs", gtk.STOCK_SAVE_AS, None, None, "Save the current project", self._saveProjectAsCb),
-            ("ProjectSettings", gtk.STOCK_PROPERTIES, "Project Settings", None, "Edit the project settings", self._projectSettingsCb),
-            ("ImportSources", gtk.STOCK_ADD, "_Import Sources...", None, "Import sources to use", self._importSourcesCb),
+            ("NewProject", gtk.STOCK_NEW, None, None, _("Create a new project"), self._newProjectCb),
+            ("OpenProject", gtk.STOCK_OPEN, None, None, _("Open an existing project"), self._openProjectCb),
+            ("SaveProject", gtk.STOCK_SAVE, None, None, _("Save the current project"), self._saveProjectCb),
+            ("SaveProjectAs", gtk.STOCK_SAVE_AS, None, None, _("Save the current project"), self._saveProjectAsCb),
+            ("ProjectSettings", gtk.STOCK_PROPERTIES, _("Project Settings"), None, _("Edit the project settings"), self._projectSettingsCb),
+            ("ImportSources", gtk.STOCK_ADD, _("_Import Sources..."), None, _("Import sources to use"), self._importSourcesCb),
+            ("ImportSourcesFolder", gtk.STOCK_ADD, _("_Import Folder of sources..."), None, _("Import folder of sources to use"), self._importSourcesFolderCb),
             ("Quit", gtk.STOCK_QUIT, None, None, None, self._quitCb),
-            ("FullScreen", gtk.STOCK_FULLSCREEN, None, None, "View the main window on the whole screen", self._fullScreenCb),
-            ("About", gtk.STOCK_ABOUT, None, None, "Information about %s" % APPNAME, self._aboutCb),
-            ("File", None, "_File"),
-            ("View", None, "_View"),
-            ("Help", None, "_Help")
+            ("FullScreen", gtk.STOCK_FULLSCREEN, None, None, _("View the main window on the whole screen"), self._fullScreenCb),
+            ("About", gtk.STOCK_ABOUT, None, None, _("Information about %s") % APPNAME, self._aboutCb),
+            ("File", None, _("_File")),
+            ("View", None, _("_View")),
+            ("Help", None, _("_Help"))
             ]
-        self.toggleactions = [
-            ("AdvancedView", None, "Advanced Vie_w", None, "Switch to advanced view", self._advancedViewCb)
+	
+	self.toggleactions = [
+            ("AdvancedView", None, _("Advanced Vie_w"), None, _("Switch to advanced view"), self._advancedViewCb)
             ]
 
         self.actiongroup = gtk.ActionGroup("mainwindow")
@@ -88,7 +98,7 @@ class PitiviMainWindow(gtk.Window):
         for action in self.actiongroup.list_actions():
             if action.get_name() in ["ProjectSettings", "Quit", "File", "Help",
                                      "About", "View", "FullScreen", "ImportSources",
-                                     "AdvancedView"]:
+                                     "ImportSourcesFolder", "AdvancedView"]:
                 action.set_sensitive(True)
             else:
                 action.set_sensitive(False)
@@ -98,7 +108,7 @@ class PitiviMainWindow(gtk.Window):
         self.uimanager.insert_action_group(self.actiongroup, 0)
         self.uimanager.add_ui_from_file(os.path.join(os.path.dirname(os.path.abspath(__file__)), "actions.xml"))
 
-        self.connect("key-press-event", self._keyPressEventCb)
+        self.connect_after("key-press-event", self._keyPressEventCb)
 
     def _createUi(self):
         """ Create the graphical interface """
@@ -114,7 +124,6 @@ class PitiviMainWindow(gtk.Window):
         vbox.pack_start(self.menu, expand=False)
 
         self.toolbar = self.uimanager.get_widget("/MainToolBar")
-        self.toolbar.set_style(gtk.TOOLBAR_ICONS)
 
         vbox.pack_start(self.toolbar, expand=False)
 
@@ -213,20 +222,29 @@ class PitiviMainWindow(gtk.Window):
         else:
             self.timeline.showSimpleView()
 
+    def _aboutResponseCb(self, dialog, unused_response):
+        dialog.destroy()
+
     def _aboutCb(self, unused_action):
 	abt = gtk.AboutDialog()
 	abt.set_name(APPNAME)
 	abt.set_version("v%s" % pitivi_version)
 	abt.set_website("http://www.pitivi.org/")
-	authors = ["Edward Hervey <edward@fluendo.com>" ]
+	authors = ["Edward Hervey <edward@fluendo.com>","",_("Contributors:"),
+                   "Christophe Sauthier <christophe.sauthier@gmail.com> (i18n)",
+                   "Laszlo Pandy <laszlok2@gmail.com> (UI)", ]
 	abt.set_authors(authors)
-	abt.set_license("GNU Lesser General Public License\nSee http://www.gnu.org/copyleft/lesser.html for more details")
+	abt.set_license(_("GNU Lesser General Public License\nSee http://www.gnu.org/copyleft/lesser.html for more details"))
         abt.set_icon_from_file(configure.get_global_pixmap_dir() + "/pitivi.png")
+        abt.connect("response", self._aboutResponseCb)
 	abt.show()
 
     def _importSourcesCb(self, unused_action):
         self.sourcefactories.sourcelist.showImportSourcesDialog()
 
+    def _importSourcesFolderCb(self, unused_action):
+        self.sourcefactories.sourcelist.showImportSourcesDialog(True)
+
     ## PiTiVi main object callbacks
 
     def _newProjectCb(self, pitivi, project):
