@@ -36,7 +36,11 @@ from urllib import unquote
 import pitivi.instance as instance
 import pitivi.dnd as dnd
 from pitivi.configure import get_pixmap_dir
-from glade import GladeWindow
+from pitivi.signalgroup import SignalGroup
+
+from filelisterrordialog import FileListErrorDialog
+
+from gettext import gettext as _
 
 def beautify_length(length):
     sec = length / gst.SECOND
@@ -95,20 +99,23 @@ class SourceListWidget(gtk.VBox):
         # Scrolled Window
         self.scrollwin = gtk.ScrolledWindow()
         self.scrollwin.set_policy(gtk.POLICY_AUTOMATIC,gtk.POLICY_AUTOMATIC)
-        self.pack_start(self.scrollwin)
 
         # Popup Menu
         self.popup = gtk.Menu()
-        additem = gtk.MenuItem("Add Sources...")
-        remitem = gtk.MenuItem("Remove Sources...")
-        playmenuitem = gtk.MenuItem("Play")
+        additem = gtk.MenuItem(_("Add Sources..."))
+        folderitem = gtk.MenuItem(_("Add Folder of Sources..."))
+        remitem = gtk.MenuItem(_("Remove Sources..."))
+        playmenuitem = gtk.MenuItem(_("Play"))
         playmenuitem.connect("activate", self._playButtonClickedCb)
         additem.connect("activate", self._addButtonClickedCb)
+        folderitem.connect("activate", self._addFolderButtonClickedCb)
         remitem.connect("activate", self._removeButtonClickedCb)
         additem.show()
+        folderitem.show()
         remitem.show()
         playmenuitem.show()
         self.popup.append(additem)
+        self.popup.append(folderitem)
         self.popup.append(remitem)
         self.popup.append(playmenuitem)
 
@@ -126,7 +133,7 @@ class SourceListWidget(gtk.VBox):
         tsel = self.treeview.get_selection()
         tsel.set_mode(gtk.SELECTION_MULTIPLE)
         
-        pixbufcol = gtk.TreeViewColumn("Icon")
+        pixbufcol = gtk.TreeViewColumn(_("Icon"))
         pixbufcol.set_expand(False)
         pixbufcol.set_spacing(5)
         self.treeview.append_column(pixbufcol)
@@ -134,7 +141,7 @@ class SourceListWidget(gtk.VBox):
         pixbufcol.pack_start(pixcell)
         pixbufcol.add_attribute(pixcell, 'pixbuf', 0)
 
-        namecol = gtk.TreeViewColumn("Information")
+        namecol = gtk.TreeViewColumn(_("Information"))
         self.treeview.append_column(namecol)
         namecol.set_expand(True)
         namecol.set_spacing(5)
@@ -143,7 +150,7 @@ class SourceListWidget(gtk.VBox):
         namecol.pack_start(txtcell)
         namecol.add_attribute(txtcell, "markup", 1)
 
-        namecol = gtk.TreeViewColumn("Duration")
+        namecol = gtk.TreeViewColumn(_("Duration"))
         namecol.set_expand(False)
         self.treeview.append_column(namecol)
         txtcell = gtk.CellRendererText()
@@ -154,23 +161,51 @@ class SourceListWidget(gtk.VBox):
         # buttons (list/icon view, add, remove)
         button = gtk.Button(stock=gtk.STOCK_ADD)
         button.connect("clicked", self._addButtonClickedCb)
+        
+        folderbutton = gtk.Button(_("Add Folder"))
+        folderbutton.set_image(gtk.image_new_from_stock(gtk.STOCK_ADD, gtk.ICON_SIZE_BUTTON))
+        folderbutton.connect("clicked", self._addFolderButtonClickedCb)
+        
+        self.errorDialogButton = gtk.ToolButton(gtk.STOCK_DIALOG_WARNING)
+        self.errorDialogButton.connect("clicked", self._errorDialogButtonClickedCb)
+        
         self.rbut = gtk.Button(stock=gtk.STOCK_REMOVE)
         self.rbut.connect("clicked", self._removeButtonClickedCb)
         self.rbut.set_sensitive(False)
-        bothbox = gtk.HBox()
-        bothbox.pack_start(button, expand=False)
-        bothbox.pack_start(self.rbut, expand=False)
-        self.pack_start(bothbox, expand=False)
+        
+        self.bothbox = gtk.HBox()
+        self.bothbox.pack_start(button, expand=False)
+        self.bothbox.pack_start(folderbutton, expand=False)
+        self.bothbox.pack_start(self.rbut, expand=False)
+        self.pack_start(self.bothbox, expand=False)
 
         # Start up with tree view
         self.scrollwin.add(self.treeview)
 
-        # callbacks from discoverer
-        # TODO : we must remove and reset the callbacks when changing project
-        instance.PiTiVi.current.sources.connect("file_added", self._fileAddedCb)
-        instance.PiTiVi.current.sources.connect("file_removed", self._fileRemovedCb)
-        instance.PiTiVi.current.sources.connect("not_media_file", self._notMediaFileCb)
+        # Explanatory message label
+        txtbuffer = gtk.TextBuffer()
+        txtbuffer.set_text(_("Import your clips by dragging them here or by using buttons below."))
+        txttag = gtk.TextTag()
+        txttag.props.size = self.style.font_desc.get_size() * 1.5
+        txtbuffer.tag_table.add(txttag)
+        txtbuffer.apply_tag(txttag, txtbuffer.get_start_iter(),
+                            txtbuffer.get_end_iter())
+        self.messagewindow = gtk.TextView(txtbuffer)
+        self.messagewindow.set_justification(gtk.JUSTIFY_CENTER)
+        self.messagewindow.set_wrap_mode(gtk.WRAP_WORD)
+        self.messagewindow.set_pixels_above_lines(50)
+        self.messagewindow.set_cursor_visible(False)
+        self.messagewindow.set_editable(False)
+        self.messagewindow.set_left_margin(10)
+        self.messagewindow.set_right_margin(10)
+        self.pack_start(self.messagewindow)
+        self.reorder_child(self.messagewindow, 0)
+        self.showingTreeView = False
 
+        # Connect to project.  We must remove and reset the callbacks when
+        # changing project.
+        self.project_signals = SignalGroup()
+        self._connectToProject(instance.PiTiVi.current)
         instance.PiTiVi.connect("new-project", self._newProjectCb)
 
         # default pixbufs
@@ -197,20 +232,65 @@ class SourceListWidget(gtk.VBox):
         # Error dialog box
         self.errorDialogBox = None
 
-    def showImportSourcesDialog(self):
+    def _connectToProject(self, project):
+        """Connect signal handlers to a project.
+
+        This first disconnects any handlers connected to an old project.
+        If project is None, this just disconnects any connected handlers.
+
+        """
+        self.project_signals.connect(project.sources, "file_added", None, self._fileAddedCb)
+        self.project_signals.connect(project.sources, "file_removed", None, self._fileRemovedCb)
+        self.project_signals.connect(project.sources, "not_media_file", None, self._notMediaFileCb)
+
+    def _displayTreeView(self, displayed=True):
+        """ Display the tree view in the scrolled window.
+        If displayed is False, then the default explanation message will be
+        shown.
+        """
+        if displayed:
+            if self.showingTreeView:
+                return
+            gst.debug("displaying tree view")
+            self.remove(self.messagewindow)
+            self.messagewindow.hide()
+            self.pack_start(self.scrollwin)
+            self.reorder_child(self.scrollwin, 0)
+            self.scrollwin.show_all()
+            self.showingTreeView = True
+        else:
+            if not self.showingTreeView:
+                return
+            gst.debug("hiding tree view")
+            self.remove(self.scrollwin)
+            self.scrollwin.hide()
+            self.pack_start(self.messagewindow)
+            self.reorder_child(self.messagewindow, 0)
+            self.messagewindow.show()
+            self.showingTreeView = False
+
+    def showImportSourcesDialog(self, select_folders=False):
         if self._importDialog:
             return
-        self._importDialog = gtk.FileChooserDialog("Import a file", None,
-                                                   gtk.FILE_CHOOSER_ACTION_OPEN,
-                                                   (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-                                                    gtk.STOCK_OPEN, gtk.RESPONSE_OK))
+            
+        if select_folders:
+                chooser_action = gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER
+                dialogtitle = _("Import a folder")
+        else:
+                chooser_action = gtk.FILE_CHOOSER_ACTION_OPEN
+                dialogtitle = _("Import a file")
+                
+        self._importDialog = gtk.FileChooserDialog(dialogtitle, None,
+                                                   chooser_action,
+                                                   (gtk.STOCK_ADD, gtk.RESPONSE_OK,
+                                                    gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE))
 
         self._importDialog.set_default_response(gtk.RESPONSE_OK)
         self._importDialog.set_select_multiple(True)
         self._importDialog.set_modal(False)
         if self._lastFolder:
             self._importDialog.set_current_folder(self._lastFolder)
-        self._importDialog.connect('response', self._dialogBoxResponseCb)
+        self._importDialog.connect('response', self._dialogBoxResponseCb, select_folders)
         self._importDialog.connect('close', self._dialogBoxCloseCb)
         self._importDialog.show()
         
@@ -218,6 +298,17 @@ class SourceListWidget(gtk.VBox):
         """ Add files to the list """
         instance.PiTiVi.current.sources.addUris(list)
 
+    def addFolders(self, list):
+        """ walks the trees of the folders in the list and adds the files it finds """
+        uriList = []
+        for folder in list:
+            if folder.startswith("file://"):
+                folder = folder[len("file://"):]
+            for path, dirs, files in os.walk(folder):
+                for afile in files:
+                    uriList.append("file://%s" % os.path.join(path, afile))
+        
+        instance.PiTiVi.current.sources.addUris(uriList)
 
     # sourcelist callbacks
     
@@ -231,26 +322,18 @@ class SourceListWidget(gtk.VBox):
             elif factory.is_audio:
                 thumbnail = self.audiofilepixbuf
         else:
-            # FIXME : Use DAR from factory
-            #pixbuf = gtk.gdk.pixbuf_new_from_file(factory.thumbnail)
             if not factory.video_info_stream:
                 desiredheight = 64 * pixbuf.get_height() / pixbuf.get_width()
             else:
                 vi = factory.video_info_stream
-                desiredheight = 64 * vi.dar.denom / vi.dar.num
+                desiredheight = int(64 / float(vi.dar))
             thumbnail = pixbuf.scale_simple(64, desiredheight, gtk.gdk.INTERP_BILINEAR)
-        if factory.is_video:
-            if factory.is_audio:
-                desc = "Audio/Video"
-            else:
-                desc = "Video"
-        else:
-            desc = "Audio"
         self.storemodel.append([thumbnail,
                                 factory.getPrettyInfo(),
                                 factory,
                                 factory.name,
                                 "<b>%s</b>" % beautify_length(factory.length)])
+        self._displayTreeView()
         self.rbut.set_sensitive(True)
 
     def _fileRemovedCb(self, unused_sourcelist, uri):
@@ -263,17 +346,26 @@ class SourceListWidget(gtk.VBox):
                 break
             piter = self.storemodel.iter_next(piter)
         if not len(self.storemodel):
+            self._displayTreeView(False)
             self.rbut.set_sensitive(False)
 
     def _notMediaFileCb(self, unused_sourcelist, uri, reason):
         """ The given uri isn't a media file """
         # popup a dialog box and fill up with reasons
         if not self.errorDialogBox:
-            # construct and display it
-            self.errorDialogBox = DiscovererErrorDialog()
+            # construct the dialog but leave it hidden
+            self.errorDialogBox = FileListErrorDialog(
+                _("Error while analyzing files"),
+                _("The following files weren't discovered properly.")
+            )
+
             self.errorDialogBox.connect('close', self._errorDialogBoxCloseCb)
             self.errorDialogBox.connect('response', self._errorDialogBoxResponseCb)
-            self.errorDialogBox.show()
+            self.errorDialogBox.hide()
+        if not self.errorDialogBox.isVisible() and not self.errorDialogButton.parent:
+            # show the button that will open the dialog
+            self.bothbox.pack_start(self.errorDialogButton, expand=False)
+            self.bothbox.show_all()
         self.errorDialogBox.addFailedFile(uri, reason)
 
 
@@ -290,17 +382,20 @@ class SourceListWidget(gtk.VBox):
 
     ## Import Sources Dialog Box callbacks
         
-    def _dialogBoxResponseCb(self, dialogbox, response):
+    def _dialogBoxResponseCb(self, dialogbox, response, select_folders):
         gst.debug("response:%r" % response)
-        dialogbox.hide()
         if response == gtk.RESPONSE_OK:
             self._lastFolder = dialogbox.get_current_folder()
             filenames = dialogbox.get_uris()
-            self.addFiles(filenames)
-        dialogbox.destroy()
-        self._importDialog = None
+            if select_folders:
+                self.addFolders(filenames)
+            else:
+                self.addFiles(filenames)
+        else:
+            dialogbox.destroy()
+            self._importDialog = None
 
-    def _dialogBoxCloseCb(self, dialogbox):
+    def _dialogBoxCloseCb(self, unused_dialogbox):
         gst.debug("closing")
         self._importDialog = None
 
@@ -310,6 +405,10 @@ class SourceListWidget(gtk.VBox):
     def _addButtonClickedCb(self, unused_widget=None):
         """ called when a user clicks on the add button """
         self.showImportSourcesDialog()
+        
+    def _addFolderButtonClickedCb(self, unused_widget=None):
+        """ called when a user clicks on the add button """
+        self.showImportSourcesDialog(select_folders=True)
 
     def _removeButtonClickedCb(self, unused_widget=None):
         """ Called when a user clicks on the remove button """
@@ -321,6 +420,13 @@ class SourceListWidget(gtk.VBox):
         for uri in uris:
             del instance.PiTiVi.current.sources[uri]
 
+    def _errorDialogButtonClickedCb(self, unused_widget=None):
+        """ called when the user click on the import errors button """
+        if self.errorDialogBox:
+            self.errorDialogBox.show()
+        if self.errorDialogButton.parent:
+            self.bothbox.remove(self.errorDialogButton)
+    
     def _playButtonClickedCb(self, unused_widget):
         """ Called when a user clicks on the play button """
         # get the selected filesourcefactory
@@ -346,29 +452,22 @@ class SourceListWidget(gtk.VBox):
         # synchronize the storemodel with the new project's sourcelist
         for uri, factory in project.sources:
             if factory:
-                length = beautify_length(factory.length)
                 if factory.thumbnail:
                     thumbnail = gtk.gdk.pixbuf_new_from_file(factory.thumbnail)
                     desiredheight = 64 * thumbnail.get_height() / thumbnail.get_width()
                     thumbnail = thumbnail.scale_simple(64, desiredheight, gtk.gdk.INTERP_BILINEAR)
                 name = os.path.basename(unquote(factory.name))
                 if factory.is_video:
-                    if factory.is_audio:
-                        desc = "Audio/Video"
-                    else:
-                        desc = "Video"
                     if not factory.thumbnail:
                         thumbnail = self.videofilepixbuf
                 else:
-                    desc = "Audio"
                     if not factory.thumbnail:
                         thumbnail = self.audiofilepixbuf
                 # FIXME : update with new table structure (icon, infotext, objectfactory, uri
                 self.storemodel.append([thumbnail, name, factory, factory.name,
                                 "<b>%s</b>" % beautify_length(factory.length)])
-        
-        instance.PiTiVi.current.sources.connect("file_added", self._fileAddedCb)
-        instance.PiTiVi.current.sources.connect("file_removed", self._fileRemovedCb)
+
+        self._connectToProject(project)
 
 
     ## Drag and Drop
@@ -387,6 +486,8 @@ class SourceListWidget(gtk.VBox):
         model, rows = self.treeview.get_selection().get_selected_rows()
         if len(rows) < 1:
             context.drag_abort(int(time.time()))
+        else:
+            self.treeview.drag_source_set_icon_pixbuf(model[rows[0]][0])
 
     def getSelectedItems(self):
         """ returns a list of selected items uri """
@@ -425,13 +526,13 @@ class AudioFxListWidget(gtk.VBox):
         self.iconview = gtk.IconView(self.storemodel)
         self.treeview = gtk.TreeView(self.storemodel)
 
-        namecol = gtk.TreeViewColumn("Name")
+        namecol = gtk.TreeViewColumn(_("Name"))
         self.treeview.append_column(namecol)
         namecell = gtk.CellRendererText()
         namecol.pack_start(namecell)
         namecol.add_attribute(namecell, "text", 0)
         
-        namecol = gtk.TreeViewColumn("Description")
+        namecol = gtk.TreeViewColumn(_("Description"))
         self.treeview.append_column(namecol)
         namecell = gtk.CellRendererText()
         namecell.set_property("ellipsize", pango.ELLIPSIZE_END)
@@ -466,13 +567,13 @@ class VideoFxListWidget(gtk.VBox):
         self.iconview = gtk.IconView(self.storemodel)
         self.treeview = gtk.TreeView(self.storemodel)
 
-        namecol = gtk.TreeViewColumn("Name")
+        namecol = gtk.TreeViewColumn(_("Name"))
         self.treeview.append_column(namecol)
         namecell = gtk.CellRendererText()
         namecol.pack_start(namecell)
         namecol.add_attribute(namecell, "text", 0)
         
-        namecol = gtk.TreeViewColumn("Description")
+        namecol = gtk.TreeViewColumn(_("Description"))
         self.treeview.append_column(namecol)
         namecell = gtk.CellRendererText()
         namecell.set_property("ellipsize", pango.ELLIPSIZE_END)
@@ -498,55 +599,3 @@ class TransitionListWidget(gtk.VBox):
         self.iconview = gtk.IconView()
         self.treeview = gtk.TreeView()
         self.pack_start(self.iconview)
-
-
-class DiscovererErrorDialog(GladeWindow):
-    """ Dialog box for showing errors from discovering files """
-    glade_file = "discoverererrordialog.glade"
-    __gsignals__ = {
-        'close': (gobject.SIGNAL_RUN_LAST,
-                  gobject.TYPE_NONE,
-                  ( )),
-        'response': (gobject.SIGNAL_RUN_LAST,
-                     gobject.TYPE_NONE,
-                     (gobject.TYPE_PYOBJECT, ))
-        }
-
-    def __init__(self):
-        GladeWindow.__init__(self)
-        self.window.set_modal(False)
-        self.treeview = self.widgets["treeview"]
-        self.window.set_geometry_hints(min_width=400, min_height=300)
-        self._setUpTreeView()
-
-    def _setUpTreeView(self):
-        self.storemodel = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING)
-        self.treeview.set_model(self.storemodel)
-
-        txtcell = gtk.CellRendererText()
-        txtcell.set_property("ellipsize", pango.ELLIPSIZE_START)
-        uricol = gtk.TreeViewColumn("File", txtcell, text=0)
-        uricol.set_expand(True)
-        self.treeview.append_column(uricol)
-
-        txtcell2 = gtk.CellRendererText()
-        txtcell2.set_property("ellipsize", pango.ELLIPSIZE_END)
-        reasoncol = gtk.TreeViewColumn("Reason", txtcell2, text=1)
-        reasoncol.set_expand(True)
-        self.treeview.append_column(reasoncol)
-
-    def addFailedFile(self, uri, reason="Unknown reason"):
-        """Add the given uri to the list of failed files. You can optionnaly
-        give a string identifying the reason why the file failed to be
-        discovered
-        """
-        gst.debug("Uri:%s, reason:%s" % (uri, reason))
-        self.storemodel.append([str(uri), str(reason)])
-
-    ## Callbacks from glade
-
-    def _closeCb(self, unused_dialog):
-        self.emit('close')
-
-    def _responseCb(self, unused_dialog, response):
-        self.emit('response', response)
