@@ -30,12 +30,16 @@ from glade import GladeWindow
 
 import plumber
 import pitivi.instance as instance
-from pitivi.bin import SmartTimelineBin, SmartDefaultBin, SmartFileBin
+from pitivi.bin import SmartTimelineBin
 from pitivi.objectfactory import FileSourceFactory
 import pitivi.dnd as dnd
 from pitivi.settings import ExportSettings
+from pitivi.signalgroup import SignalGroup
+
 from exportsettingswidget import ExportSettingsDialog
 
+from gettext import gettext as _
+
 def time_to_string(value):
     if value == -1:
         return "--m--s---"
@@ -60,20 +64,31 @@ class PitiviViewer(gtk.VBox):
         self.currentState = gst.STATE_PAUSED
         self._createUi()
 
-        # connect to the sourcelist for temp factories
-        # TODO remove/replace the signal when closing/opening projects
-        instance.PiTiVi.current.sources.connect("tmp_is_ready", self._tmpIsReadyCb)
-
+        # Connect to project.  We must remove and reset the callbacks when
+        # changing project.
+        self.project_signals = SignalGroup()
+        self._connectToProject(instance.PiTiVi.current)
         instance.PiTiVi.connect("new-project", self._newProjectCb)
         instance.PiTiVi.playground.connect("current-state", self._currentStateCb)
-        instance.PiTiVi.playground.connect("bin-added", self._binAddedCb)
-        instance.PiTiVi.playground.connect("bin-removed", self._binRemovedCb)
         instance.PiTiVi.playground.connect("position", self._playgroundPositionCb)
 
-        instance.PiTiVi.current.settings.connect("settings-changed",
-                                                 self._settingsChangedCb)
+        # callback to know when to set the XID on our viewer widget
+        instance.PiTiVi.playground.connect("element-message", self._playgroundElementMessageCb)
+
         self._addTimelineToPlayground()
 
+    def _connectToProject(self, project):
+        """Connect signal handlers to a project.
+ 
+        This first disconnects any handlers connected to an old project.
+        If project is None, this just disconnects any connected handlers.
+ 
+        """
+        self.project_signals.connect(project.sources, "tmp_is_ready",
+                                     None, self._tmpIsReadyCb)
+        self.project_signals.connect(project, "settings-changed",
+                                     None, self._settingsChangedCb)
+
     def _createUi(self):
         """ Creates the Viewer GUI """
         self.set_border_width(5)
@@ -135,27 +150,14 @@ class PitiviViewer(gtk.VBox):
         self.forward_button.connect("clicked", self._forwardCb)
         self.forward_button.set_sensitive(False)
         bbox.pack_start(self.forward_button, expand=False)
-        
-        infohbox = gtk.HBox()
-        infohbox.set_spacing(5)
-        self.pack_start(infohbox, expand=False)
 
-        # available sources combobox
-        self.sourcelist = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_PYOBJECT)
-        self.sourcecombobox = gtk.ComboBox(self.sourcelist)
-        cell = gtk.CellRendererText()
-        self.sourcecombobox.pack_start(cell, True)
-        self.sourcecombobox.add_attribute(cell, "text", 0)
-        self.sourcecombobox.set_sensitive(False)
-        self.sourcecombobox.connect("changed", self._comboboxChangedCb)
-        
         # current time
         self.timelabel = gtk.Label()
         self.timelabel.set_markup("<tt>00m00s000 / --m--s---</tt>")
         self.timelabel.set_alignment(1.0, 0.5)
-        self.timelabel.set_padding(5, 5)
-        infohbox.pack_start(self.sourcecombobox, expand=True)
-        infohbox.pack_end(self.timelabel, expand=False)
+        self.timelabel.set_padding(5, 5)        
+        bbox.pack_start(self.timelabel, expand=False, padding=10)
+        
 
         # drag and drop
         self.drag_dest_set(gtk.DEST_DEFAULT_DROP | gtk.DEST_DEFAULT_MOTION,
@@ -195,6 +197,7 @@ class PitiviViewer(gtk.VBox):
         vqueue = gst.element_factory_make('queue')
         cspace = gst.element_factory_make('ffmpegcolorspace')
         vscale = gst.element_factory_make('videoscale')
+        vscale.props.method = 1
         vsinkthread.add(self.videosink, vqueue, vscale, cspace)
         vqueue.link(self.videosink)
         cspace.link(vscale)
@@ -202,10 +205,9 @@ class PitiviViewer(gtk.VBox):
         vsinkthread.videosink = self.videosink
         vsinkthread.add_pad(gst.GhostPad("sink", cspace.get_pad('sink')))
 
-        vsinkthread.get_pad("sink").connect("notify::caps", self._videosinkCapsNotifyCb)
+        self.videosink.get_pad("sink").connect("notify::caps", self._videosinkCapsNotifyCb)
 
         self.drawingarea.videosink = self.videosink
-        self.videosink.set_xwindow_id(self.drawingarea.window.xid)
 
         # audio elements
         gst.debug("Creating audio sink")
@@ -224,10 +226,11 @@ class PitiviViewer(gtk.VBox):
         instance.PiTiVi.playground.setAudioSinkThread(asinkthread)
         instance.PiTiVi.playground.connect("current-changed", self._currentPlaygroundChangedCb)
 
-    def _settingsChangedCb(self, unused_settings):
+    def _settingsChangedCb(self, unused_project):
         gst.info("current project settings changed")
         # modify the ratio if it's the timeline that's playing
-        raise NotImplementedError
+        # FIXME : do we really need to modify the ratio ??
+        pass
 
     def _drawingAreaRealizeCb(self, drawingarea):
         drawingarea.modify_bg(gtk.STATE_NORMAL, drawingarea.style.black)
@@ -260,8 +263,9 @@ class PitiviViewer(gtk.VBox):
     def _sliderValueChangedCb(self, slider):
         """ seeks when the value of the slider has changed """
         value = long(slider.get_value())
-        gst.info(time_to_string(value))
-        self._doSeek(value)
+        gst.info(gst.TIME_ARGS(value))
+        if self.moving_slider:
+            self._doSeek(value)
 
     def _sliderScrollCb(self, unused_slider, event):
         # calculate new seek position
@@ -294,7 +298,7 @@ class PitiviViewer(gtk.VBox):
             gobject.timeout_add(80, self._seekTimeoutCb)
             instance.PiTiVi.playground.seekInCurrent(value, format)
             self._newTime(value)
-        elif format == gst.FORMAT_TIME:
+        if format == gst.FORMAT_TIME:
             self.requested_time = value
 
     def _newTime(self, value, frame=-1):
@@ -306,16 +310,6 @@ class PitiviViewer(gtk.VBox):
             self.posadjust.set_value(float(value))
         return False
 
-    ## gtk.ComboBox callbacks for sources
-
-    def _comboboxChangedCb(self, cbox):
-        # selected another source
-        idx = cbox.get_active()
-        # get the corresponding smartbin
-        smartbin = self.sourcelist[idx][1]
-        if not instance.PiTiVi.playground.current == smartbin:
-            instance.PiTiVi.playground.switchToPipeline(smartbin)
-
 
     ## active Timeline calllbacks
 
@@ -328,9 +322,16 @@ class PitiviViewer(gtk.VBox):
         self.timelabel.set_markup("<tt>%s / %s</tt>" % (time_to_string(self.current_time), time_to_string(instance.PiTiVi.playground.current.length)))
         
 
+    def _backToDefaultCb(self):
+        instance.PiTiVi.playground.switchToDefault()
+        instance.PiTiVi.playground.play()
+        self._newTime(0)
+
     def _timelineDurationChangedCb(self, unused_composition, unused_start,
                                    duration):
         gst.debug("duration : %d" % duration)
+        if duration == 0:
+            gobject.idle_add(self._backToDefaultCb)
         gobject.idle_add(self._asyncTimelineDurationChanged, duration)
 
     def _dndDataReceivedCb(self, unused_widget, context, unused_x, unused_y,
@@ -356,10 +357,10 @@ class PitiviViewer(gtk.VBox):
         gst.info("%s" % factory)
         instance.PiTiVi.playground.playTemporaryFilesourcefactory(factory)
 
-    def _newProjectCb(self, unused_pitivi, unused_project):
+    def _newProjectCb(self, unused_pitivi, project):
         """ the current project has changed """
-        instance.PiTiVi.current.sources.connect("tmp_is_ready", self._tmpIsReadyCb)
-        instance.PiTiVi.current.settings.connect("settings-changed", self._settingsChangedCb)
+        assert(instance.PiTiVi.current == project)
+        self._connectToProject(project)
         
     def _addTimelineToPlayground(self):
         instance.PiTiVi.playground.addPipeline(instance.PiTiVi.current.getBin())
@@ -399,11 +400,16 @@ class PitiviViewer(gtk.VBox):
 
     ## Playground callbacks
     
-    def _playgroundPositionCb(self, playground, smartbin, pos):
+    def _playgroundPositionCb(self, unused_playground, unused_smartbin, pos):
         self._newTime(pos)
 
     def _currentPlaygroundChangedCb(self, playground, smartbin):
-        if not smartbin == playground.default:
+        gst.log("smartbin:%s" % smartbin)
+        if smartbin == playground.default:
+            self.slider.set_sensitive(False)
+            self.playpause_button.set_sensitive(False)
+            self.record_button.set_sensitive(False)
+        else:
             if isinstance(smartbin, SmartTimelineBin):
                 gst.info("switching to Timeline, setting duration to %s" % (gst.TIME_ARGS(smartbin.project.timeline.videocomp.duration)))
                 self.posadjust.upper = float(smartbin.project.timeline.videocomp.duration)
@@ -419,41 +425,24 @@ class PitiviViewer(gtk.VBox):
             self._newTime(0)
             self.slider.set_sensitive(True)
             self.playpause_button.set_sensitive(True)
-        self.sourcecombobox.set_active(self._getSmartbinIndex(smartbin))
 
-    def _binAddedCb(self, unused_playground, smartbin):
-        # a smartbin was added
-        # check if the item isn't already in the sourcelist:
-        self.sourcecombobox.set_sensitive(True)
-        for name, bin in self.sourcelist:
-            if name == smartbin.displayname:
-                return
-        self.sourcelist.append([smartbin.displayname, smartbin])
-
-    def _getSmartbinIndex(self, smartbin):
-        # find the index of a smartbin
-        # return -1 if it's not in there
-        for pos in range(len(self.sourcelist)):
-            if self.sourcelist[pos][0] == smartbin.displayname:
-                return pos
-        return -1
-
-    def _binRemovedCb(self, unused_playground, smartbin):
-        # a smartbin was removed
-        idx = self._getSmartbinIndex(smartbin)
-        if idx < 0:
-            return
-        del self.sourcelist[idx]
-        if not self.sourcelist:
-            self.sourcecombobox.set_sensitive(False)
-
-    def _currentStateCb(self, playground, state):
+    def _currentStateCb(self, unused_playground, state):
         gst.info("current state changed : %s" % state)
         if state == int(gst.STATE_PLAYING):
             self.playpause_button.setPause()
         elif state == int(gst.STATE_PAUSED):
             self.playpause_button.setPlay()
 
+    def _playgroundElementMessageCb(self, unused_playground, message):
+        name = message.structure.get_name()
+        gst.log('message:%s / %s' % (message, name))
+        if name == 'prepare-xwindow-id':
+            dav = self.drawingarea.videosink
+            gst.log('%s' % dav)
+            if dav and dav.realsink and dav.realsink == message.src:
+                self.drawingarea.can_set_xid = True
+                self.drawingarea.set_xwindow_id()
+
 
 class ViewerWidget(gtk.DrawingArea):
     """
@@ -466,17 +455,32 @@ class ViewerWidget(gtk.DrawingArea):
         gtk.DrawingArea.__init__(self)
         self.videosink = None
         self.have_set_xid = False
+        self.can_set_xid = False
         self.unset_flags(gtk.DOUBLE_BUFFERED)
+        self.unset_flags(gtk.SENSITIVE)
 
     def do_expose_event(self, unused_event):
         """ 'expose-event' override """
         if self.videosink:
-            if not self.have_set_xid:
-                self.videosink.set_xwindow_id(self.window.xid)
-                self.have_set_xid = True
-            self.videosink.expose()
+            if not self.have_set_xid and self.can_set_xid:
+                self.set_xwindow_id()
+            elif self.have_set_xid:
+                self.videosink.expose()
         return False
 
+    def set_xwindow_id(self):
+        """ set the widget's XID on the configured videosink. """
+        gst.log("...")
+        if not self.videosink:
+            return
+        if self.have_set_xid:
+            return
+        gst.log("About to set %s's xid to %d" % (self.videosink,
+                                                 self.window.xid))
+        self.videosink.set_xwindow_id(self.window.xid)
+        self.have_set_xid = True
+        self.videosink.expose()
+
 
 class PlayPauseButton(gtk.Button):
     """ Double state gtk.Button which displays play/pause """
@@ -531,12 +535,19 @@ class EncodingDialog(GladeWindow):
         self.cancelbutton = self.widgets["cancelbutton"]
         self.positionhandler = 0
         self.rendering = False
-        self.settings = project.settings
+        self.settings = project.getSettings()
         self.timestarted = 0
+        self.vinfo = self.widgets["videoinfolabel"]
+        self.ainfo = self.widgets["audioinfolabel"]
+        self._displaySettings()
+
+    def _displaySettings(self):
+        self.vinfo.set_markup(self.settings.getVideoDescription())
+        self.ainfo.set_markup(self.settings.getAudioDescription())
 
     def _fileButtonClickedCb(self, button):
         
-        dialog = gtk.FileChooserDialog(title="Choose file to render to",
+        dialog = gtk.FileChooserDialog(title=_("Choose file to render to"),
                                        parent=self.window,
                                        buttons=(gtk.STOCK_OK, gtk.RESPONSE_ACCEPT,
                                                 gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT),
@@ -550,13 +561,13 @@ class EncodingDialog(GladeWindow):
             button.set_label(os.path.basename(self.outfile))
         dialog.destroy()
 
-    def _positionCb(self, playground, smartbin, position):
+    def _positionCb(self, unused_playground, unused_smartbin, position):
         timediff = time.time() - self.timestarted
         self.progressbar.set_fraction(float(position) / float(self.bin.length))
         if timediff > 5.0:
             # only display ETA after 5s in order to have enough averaging
             totaltime = (timediff * float(self.bin.length) / float(position)) - timediff
-            self.progressbar.set_text("Finished in %dm%ds" % (int(totaltime) / 60,
+            self.progressbar.set_text(_("Finished in %dm%ds") % (int(totaltime) / 60,
                                                               int(totaltime) % 60))
 
     def _recordButtonClickedCb(self, unused_button):
@@ -566,9 +577,9 @@ class EncodingDialog(GladeWindow):
                 self.positionhandler = instance.PiTiVi.playground.connect('position', self._positionCb)
                 self.rendering = True
                 self.cancelbutton.set_label("gtk-cancel")
-                self.progressbar.set_text("Rendering")
+                self.progressbar.set_text(_("Rendering"))
             else:
-                self.progressbar.set_text("Couldn't start rendering")
+                self.progressbar.set_text(_("Couldn't start rendering"))
 
     def _settingsButtonClickedCb(self, unused_button):
         dialog = ExportSettingsDialog(self.settings)
@@ -576,6 +587,7 @@ class EncodingDialog(GladeWindow):
         dialog.hide()
         if res == gtk.RESPONSE_ACCEPT:
             self.settings = dialog.getSettings()
+            self._displaySettings()
         dialog.destroy()
 
     def do_destroy(self):
@@ -588,7 +600,7 @@ class EncodingDialog(GladeWindow):
         if self.positionhandler:
             instance.PiTiVi.playground.disconnect(self.positionhandler)
             self.positionhandler = 0
-        self.progressbar.set_text("Rendering Complete")
+        self.progressbar.set_text(_("Rendering Complete"))
         self.progressbar.set_fraction(1.0)
         self.cancelbutton.set_label("gtk-close")
         
